pub struct Party {
pub party_state: Option<CharacterState>,
pub party_adjusted_power: Option<i64>,
pub available_players: Vec<PartyMemberPreview>,
}Fields
party_state: Option<CharacterState>party_adjusted_power: Option<i64>available_players: Vec<PartyMemberPreview>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Party
impl<'de> Deserialize<'de> for Party
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl IntoWasmAbi for Party
impl IntoWasmAbi for Party
Sourceimpl JsonSchema for Party
impl JsonSchema for Party
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionIntoWasmAbi for Party
impl OptionIntoWasmAbi for Party
Sourceimpl Tsify for Party
impl Tsify for Party
const DECL: &'static str = "export interface Party {\n party_state: CharacterState | null;\n party_adjusted_power: number | null;\n available_players: PartyMemberPreview[];\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorIntoWasmAbi for Party
impl VectorIntoWasmAbi for Party
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
impl Eq for Party
impl StructuralPartialEq for Party